from datetime import datetime

from schoolmospy.core.basic_client import BasicClient
from schoolmospy.models.homeworks import Homeworks


class HomeworkClient:
    def __init__(self, client: BasicClient) -> None:
        """
        Initialization the HomeworkClient instance.

        Args:
            client (BasicClient): An instance of BasicClient or any compatible subclass,
                used for making API requests.
        """
        self.client = client

    async def get(self, from_date: datetime, to_date: datetime) -> Homeworks:
        """
        Method for getting homework done within a certain period of time

        Args:
            from_date (datetime): The start date of the period (inclusive).
            to_date (datetime): The end date of the period (inclusive).

        Returns:
            Homeworks: A Pydantic model containing a list of homework items.

        Raises:
            APIError: If the request fails or returns an unexpected response.
            AuthError: If the provided token is invalid or expired.

        Example:
            ```python
            from datetime import datetime
            from schoolmospy.clients.student_client import StudentClient

            client = StudentClient(token="YOUR_TOKEN", profile_id=17234613)
            homeworks = await client.homework.get(
                from_date=datetime(2025, 10, 1),
                to_date=datetime(2025, 10, 24)
            )
            print(homeworks.payload)
            ```
        """

        return await self.client.get(
            "/api/family/web/v1/homeworks",
            Homeworks,
            params={
                "from": from_date.strftime("%Y-%m-%d"),
                "to": to_date.strftime("%Y-%m-%d"),
                "student_id": self.client.profile_id,
            },
        )



from datetime import datetime

from schoolmospy.core.basic_client import BasicClient
from schoolmospy.models.events import Events


class EventClient:
    def __init__(self, client: BasicClient) -> None:
        """
        Initialization the EventClient instance.

        Args:
            client (BasicClient): An instance of BasicClient or any compatible subclass,
                used for making API requests.
        """
        self.client = client

    async def get(self, from_date: datetime, to_date: datetime, contingent_guid: str) -> Events:
        """
        Method for getting events done within a certain period of time

        Args:
            from_date (datetime): The start date of the period (inclusive).
            to_date (datetime): The end date of the period (inclusive).
            contingent_guid (str): Person ID

        Returns:
            Events: A Pydantic model containing a list of events items.

        Raises:
            APIError: If the request fails or returns an unexpected response.
            AuthError: If the provided token is invalid or expired.

        Example:
            ```python
            from datetime import datetime
            from schoolmospy.clients.student_client import StudentClient

            client = StudentClient(token="YOUR_TOKEN", profile_id=17234613)

            me = await client.get_me()

            events = await client.events.get(
                from_date=datetime(2025, 10, 1),
                to_date=datetime(2025, 10, 24),
                contingent_guid=me.contingent_guid
            )
            print(events.response)
            ```
        """

        return await self.client.get(
            "/api/eventcalendar/v1/api/events",
            Events,
            params={
                "begin_date": from_date.strftime("%Y-%m-%d"),
                "end_date": to_date.strftime("%Y-%m-%d"),
                "person_ids": contingent_guid,
                "expand": "marks,homework,absence_reason_id,health_status,nonattendance_reason_id",
                "source_types": "PLAN,AE,EC,EVENTS,AFISHA,ORGANIZER,OLYMPIAD,PROF",
            },
            headers={"X-Mes-Role": "student"},
        )



from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class EventItem(BaseModel):
    id: int
    source_id: str
    source: str
    start_at: str
    finish_at: str
    cancelled: bool | None = None
    lesson_type: str | None = None
    course_lesson_type: Any | None = None
    lesson_form: Any | None = None
    replaced: bool | None = None
    room_name: str | None
    room_number: str | None
    subject_id: int | None = None
    subject_name: str
    link_to_join: Any | None = None
    health_status: Any
    absence_reason_id: Any
    nonattendance_reason_id: Any
    homework: Any | None = None
    marks: Any | None = None
    is_missed_lesson: bool
    esz_field_id: int | None = None
    lesson_theme: Any | None = None


class Events(BaseModel):
    total_count: int
    response: list[EventItem]
    errors: Any
